@@ -115,7 +115,7 @@ class FullVirtGuest(Guest.XenGuest):
 
     def __init__(self, type=None, arch=None, connection=None, hypervisorURI=None, emulator=None, installer=None):
         if not installer:
-            installer = DistroManager.DistroInstaller(type = type)
+            installer = DistroManager.DistroInstaller(type = type, os_type = "hvm")
         Guest.Guest.__init__(self, type, connection, hypervisorURI, installer)
         self.disknode = "hd"
         self.features = { "acpi": None, "pae": util.is_pae_capable(), "apic": None }
@@ -171,6 +171,9 @@ class FullVirtGuest(Guest.XenGuest):
                     features[f] = FullVirtGuest.OS_TYPES[os_type]["variants"][os_variant][f]
                 else:
                     features[f] = FullVirtGuest.OS_TYPES[os_type][f]
+            else:
+                if features[f] is None:
+                    features[f] = True
         return features
 
     def get_os_distro(self):
