@@ -273,41 +273,66 @@ class VirtualNetworkInterface:
         else:
             raise ValueError, _("Unknown network type %s") % (type,)
 
-    def setup(self, conn):
+    def is_conflict_net(self, conn):
+        """is_conflict_net: determines if mac conflicts with others in system
+
+           returns a two element tuple: 
+               first element is True if fatal collision occured
+               second element is a string description of the collision.
+           Non fatal collisions (mac addr collides with inactive guest) will
+           return (False, "description of collision")"""
         # get Running Domains
         ids = conn.listDomainsID();
         vms = []
         for id in ids:
-            vm = conn.lookupByID(id)
-            vms.append(vm)
+            try:
+                vm = conn.lookupByID(id)
+                vms.append(vm)
+            except libvirt.libvirtError:
+                # guest probably in process of dieing
+                logging.warn("conflict_net: Failed to lookup domain id %d" % id)
         # get inactive Domains
         inactive_vm = []
         names = conn.listDefinedDomains()
         for name in names:
-            vm = conn.lookupByName(name)
-            inactive_vm.append(vm)
+            try:
+                vm = conn.lookupByName(name)
+                inactive_vm.append(vm)
+            except:
+                # guest probably in process of dieing
+                logging.warn("conflict_net: Failed to lookup domain %d" % name)
 
         # get the Host's NIC MACaddress
         hostdevs = util.get_host_network_devices()
 
+        if self.countMACaddr(vms) > 0:
+            return (True, _("The MAC address you entered is already in use by another virtual machine!"))
+        for (dummy, dummy, dummy, dummy, host_macaddr) in hostdevs:
+            if self.macaddr.upper() == host_macaddr.upper():
+                return (True, _("The MAC address you entered conflicts with the physical NIC."))
+        if self.countMACaddr(inactive_vm) > 0:
+            return (False, _("The MAC address you entered is already in use by another inactive virtual machine!"))
+        return (False, None)
+
+    def setup(self, conn):
+
         # check conflict MAC address
         if self.macaddr is None:
             while 1:
                 self.macaddr = util.randomMAC()
-                if self.countMACaddr(vms) > 0:
+                if self.is_conflict_net(conn)[1] is not None:
                     continue
                 else:
                     break
         else:
-            if self.countMACaddr(vms) > 0:
-                raise RuntimeError, _("The MAC address you entered is already in use by another virtual machine!")
-            for (dummy, dummy, dummy, dummy, host_macaddr) in hostdevs:
-                if self.macaddr.upper() == host_macaddr.upper():
-                    raise RuntimeError, _("The MAC address you entered conflicts with the physical NIC.")
-            if self.countMACaddr(inactive_vm) > 0:
-                msg = _("The MAC address you entered is already in use by another inactive virtual machine!")
-                print >> sys.stderr, msg
-                logging.warning(msg)
+            ret, msg = self.is_conflict_net(conn)
+            if msg is not None:
+                # Error message found
+                if ret is False:
+                    # Not fatal
+                    logging.warning(msg)
+                else:
+                    raise RuntimeError(msg)
 
         if not self.bridge and self.type == "bridge":
             self.bridge = util.default_bridge()
@@ -407,11 +432,12 @@ class XenSDLGraphics(SDLVirtualGraphics):
     pass
 
 class Installer(object):
-    def __init__(self, type = "xen", location = None, boot = None, extraargs = None):
+    def __init__(self, type = "xen", location = None, boot = None, extraargs = None, os_type = None):
         self._location = None
         self._extraargs = None
         self._boot = None
         self._cdrom = False
+        self._os_type = os_type
         self._install_disk = None   # VirtualDisk that contains install media
 
         if type is None:
@@ -443,6 +469,12 @@ class Installer(object):
         self._type = val
     type = property(get_type, set_type)
 
+    def get_os_type(self):
+        return self._os_type
+    def set_os_type(self, val):
+        self._os_type = val
+    os_type = property(get_os_type, set_os_type)
+
     def get_scratchdir(self):
         if self.type == "xen":
             return "/var/lib/xen"
@@ -595,7 +627,7 @@ class Guest(object):
     def get_vcpus(self):
         return self._vcpus
     def set_vcpus(self, val):
-        maxvcpus = util.get_max_vcpus(self.conn)
+        maxvcpus = util.get_max_vcpus(self.conn, self.type)
         if val < 1 or val > maxvcpus:
             raise ValueError, \
                   _("Number of vcpus must be in the range of 1-%d") % (maxvcpus,)
